@@ -26,6 +26,12 @@ else:
     # matplotlib deletes link from os namespace, expected distutils workaround
     link_func = shutil.copyfile
 
+if hasattr(shutil, 'which'):
+    which = shutil.which
+else:
+    from stdeb.which import which
+
+
 __all__ = ['DebianInfo', 'build_dsc', 'expand_tarball', 'expand_zip',
            'stdeb_cmdline_opts', 'stdeb_cmd_bool_opts', 'recursive_hardlink',
            'apply_patch', 'repack_tarball_with_debianized_dirname',
@@ -132,6 +138,8 @@ stdeb_cmdline_opts = [
      'dh_systemd_start helpers at the correct time during build.'),
     ('sign-results', None,
      'Use gpg to sign the resulting .dsc and .changes file'),
+    ('sign-key=', None,
+     'Specify signing key'),
     ('ignore-source-changes', None,
      'Ignore all changes on source when building source package (add -i.* '
      'option to dpkg-source)'),
@@ -1114,6 +1122,14 @@ class DebianInfo:
 
         if not (with_python2 or with_python3):
             raise RuntimeError('nothing to do - neither Python 2 or 3.')
+
+        if with_python2:
+            if which("python"):
+                self.python2_binname = "python"
+            elif which("python2"):
+                self.python2_binname = "python2"
+            else:
+                raise RuntimeError("Python 2 binary not found on path as either `python` or `python2`")
         sequencer_with = []
         if with_python2:
             sequencer_with.append('python2')
@@ -1336,6 +1352,7 @@ def build_dsc(debinfo,
               remove_expanded_source_dir=0,
               debian_dir_only=False,
               sign_dsc=False,
+              sign_key=None,
               ignore_source_changes=False,
               ):
     """make debian source package"""
@@ -1468,8 +1485,12 @@ def build_dsc(debinfo,
         fname = debinfo.udev_rules
         if not os.path.exists(fname):
             raise ValueError('udev rules file specified, but does not exist')
-        link_func(fname,
-                  os.path.join(debian_dir, '%s.udev' % debinfo.package))
+        if debinfo.with_python2:
+            link_func(fname,
+                      os.path.join(debian_dir, '%s.udev' % debinfo.package))
+        if debinfo.with_python3:
+            link_func(fname,
+                      os.path.join(debian_dir, '%s.udev' % debinfo.package3))
 
     #    J. debian/source/format
     os.mkdir(os.path.join(debian_dir, 'source'))
@@ -1562,6 +1583,8 @@ def build_dsc(debinfo,
 
     if not sign_dsc:
         args += ['-uc', '-us']
+    elif sign_key is not None:
+        args += ['--sign-key={}'.format(sign_key)]
 
     if ignore_source_changes:
         args.append('-i.*')
@@ -1641,7 +1664,7 @@ RULES_MAIN = """\
 %(binary_target_lines)s
 """
 
-RULES_OVERRIDE_CLEAN_TARGET_PY2 = "        python setup.py clean -a"
+RULES_OVERRIDE_CLEAN_TARGET_PY2 = "        %(python2_binname)s setup.py clean -a"
 RULES_OVERRIDE_CLEAN_TARGET_PY3 = "        python3 setup.py clean -a"
 RULES_OVERRIDE_CLEAN_TARGET = r"""
 override_dh_auto_clean:
@@ -1649,14 +1672,14 @@ override_dh_auto_clean:
         find . -name \*.pyc -exec rm {} \;
 """
 
-RULES_OVERRIDE_BUILD_TARGET_PY2 = "        python setup.py build --force"
+RULES_OVERRIDE_BUILD_TARGET_PY2 = "        %(python2_binname)s setup.py build --force"
 RULES_OVERRIDE_BUILD_TARGET_PY3 = "        python3 setup.py build --force"
 RULES_OVERRIDE_BUILD_TARGET = """
 override_dh_auto_build:
 %(rules_override_build_target_pythons)s
 """
 
-RULES_OVERRIDE_INSTALL_TARGET_PY2 = "        python setup.py install --force --root=debian/%(package)s --no-compile -O0 --install-layout=deb %(install_prefix)s %(no_python2_scripts_cli_args)s"  # noqa: E501
+RULES_OVERRIDE_INSTALL_TARGET_PY2 = "        %(python2_binname)s setup.py install --force --root=debian/%(package)s --no-compile -O0 --install-layout=deb %(install_prefix)s %(no_python2_scripts_cli_args)s"  # noqa: E501
 
 RULES_OVERRIDE_INSTALL_TARGET_PY3 = "        python3 setup.py install --force --root=debian/%(package3)s --no-compile -O0 --install-layout=deb %(install_prefix)s %(no_python3_scripts_cli_args)s"  # noqa: E501
 
